#!/usr/bin/env python
# -*- coding: utf-8 -*-

# file      : fbx.py
# project   : fricorder
# copyright : (C) 2013 by Claude Bulin
#
# This file is part of fricorder project
#
# This library is free software; you can redistribute it and/or
# modify it under the terms of the GNU Lesser General Public
# License as published by the Free Software Foundation; version 3.
#
# This library is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
# Lesser General Public License for more details.
#
# You should have received a copy of the GNU Lesser General Public
# License along with this library; if not, write to the Free Software
# Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307
# USA


import urllib.request
import os
import io
from fconfig import FConfig
# init the foreign language
import Language_Init
_ = Language_Init.Translator(FConfig).lang.gettext

def getStreams():
	"""
	recupere une liste de tuple (num, nom chaine, stream) directement sur la freebox
	"""
	list_tv = []
	chaine = None
	num=None
	bool_remove = False

	try:
		print('try:')
		print('  get freebox-list from web')
		# get freebox-list from web
		list_file = urllib.request.urlopen("http://mafreebox.freebox.fr/freeboxtv/playlist.m3u")
		# save on disk
		print('  save on disk')
		fichier = open(os.path.join(FConfig.CACHEDIR, "LISTE_M3U.txt"), "wt")
		for i in list_file:
			fichier.write(  i.decode( 'utf-8' ))
		fichier.close()
		# open freebox-list from disk-file
		print('  open freebox-list from disk-file')
		list_file = io.open(os.path.join(FConfig.CACHEDIR, "LISTE_M3U.txt"), "rt", encoding='UTF-8')
		bool_remove = True

	except:
		print('except:')
		print('  get freebox-list from disk-file')
		# get freebox-list from disk-file
		list_file = open(os.path.join(FConfig.CACHEDIR,"playlist.m3u"), "rt", encoding='UTF-8')

	for i in list_file:
		ligne = i.strip()
		if ligne:
			if chaine:
				list_tv.append( (num,chaine,ligne) )
				chaine=None
			if ligne[:7]=="#EXTINF":
				line=ligne.split(" - ")
				chaine = line[-1]
				num=int(line[0].split(",")[-1])

	if bool_remove == True:
		os.remove(os.path.join(FConfig.CACHEDIR, "LISTE_M3U.txt"))

	return list_tv

def convChaine(fchaine):
	""" convertit une chaine freebox en chaine *progTV* (chaine du grabber tv_grab_fr)
	"""
	fchaine=fchaine.lower().strip()
	if fchaine[:8]=="france 3":
		#permet de mapper toutes les fr3
		return "france3"
	else:
		t={
			"rtl9"              :u'rtl9',
			"ab 1"              :u'ab1',
			"tv5"               :u'tv5',
			"mtv france"        :u'mtv',
			"france 2"          :u'france2',
			"france 4"          :u'france4',
			"arte"              :u'arte',
			"arte allemand"     :u'arte',
			"france 5"          :u'france5',
		}
		if fchaine in t.keys():
			#utilise le dictionnaire de mappage plus haut
			return t[fchaine]
		else:
			#retourne la chaine freebox en minuscule ! (ca marche pour "arte", par ex)
			return fchaine

if __name__ == "__main__":
	os.chdir("..")
	l=getStreams()
	assert len(l)>0
	assert convChaine("France 3 Picardie") == "france3"
	assert convChaine("France 4") == "france4"
	assert convChaine(" ABCDEF ") == "abcdef"
